==> tencentcloud-edgeone-migration-nodejs-v2-0.0.4.tgz: package/src/transfer/PathBasedOrigin.js <==
const utils = require('../utils');
const logger = require('../logger');
const { t } = require("../../i18n/trans")

function PathBasedOrigin(domain, domainConfig, ruleTransferLog) {
  const keyConfig = domainConfig.Origin.PathBasedOrigin;
  if (!keyConfig || !keyConfig.length) {
    ruleTransferLog.push({
      config: t('分路径回源配置(Origin.PathBasedOrigin)'),
      result: t('未配置'),
      detail: ''
    });
    return null;
  }

  const pathConfig = keyConfig.filter(rule => {
    return rule.RuleType === 'path';
  });

  if (pathConfig && pathConfig.length > 0) {
    logger.error(t('EO不支持修改全路径文件的回源配置'));
  }

  const newKeyConfig = keyConfig.filter(rule => {
    return rule.RuleType !== 'path';
  });

  const eoRules = [];
  newKeyConfig.reverse().forEach(rule => {
    const [origin, port, weight] = rule.Origin[0].split(':');

    let eoRule = {
      'Conditions': [
        {
          'Conditions': [
            {
              'Operator': 'equal',
              'Target': utils.getTarget(rule.RuleType),
              'IgnoreCase': false,
              'Values': rule.RuleType === 'path' ? rule.RulePaths.map(path => {
                return `https://${domain}${path}`;
              }) : rule.RulePaths
            }
          ]
        }
      ],
      'Actions': [
        {
          'NormalAction': {
            'Action': 'Origin',
            'Parameters': [
              {
                'Name': 'Type',
                'Values': [
                  'IP_DOMAIN'
                ]
              },
              {
                'Name': 'DomainName',
                'Values': [origin]
              },
              {
                'Name': 'OriginProtocol',
                'Values': [
                  'follow'
                ]
              },
              {
                'Name': 'HttpOriginPort',
                'Values': [port !== undefined ? port : '80']
              },
              {
                'Name': 'HttpsOriginPort',
                'Values': [port !== undefined ? port : '443']
              }
            ]
          }
        }
      ]
    };
    eoRules.push(eoRule);

  });

  if (pathConfig && pathConfig.length > 0) {
    ruleTransferLog.push({
      config: t('分路径回源配置(Origin.PathBasedOrigin)'),
      result: t('部分失败'),
      detail: t('EO不支持修改全路径文件的回源配置')
    });
  }
  else {
    ruleTransferLog.push({
      config: t('分路径回源配置(Origin.PathBasedOrigin)'),
      result: t('成功'),
      detail: ''
    });

  }
  return {
    'Rules': eoRules,
    'Tags': []
  };
}

module.exports = PathBasedOrigin;

==> tencentcloud-edgeone-migration-nodejs-v2-0.0.12.tgz: package/src/transfer/PathBasedOrigin.js <==
const utils = require('../utils');
const { t } = require("../../i18n/trans");
const genLog = require("../../logGenerator");

function PathBasedOrigin(domain, domainConfig, ruleTransferLog) {
  const keyConfig = domainConfig.Origin.PathBasedOrigin;
  if (!keyConfig || !keyConfig.length) {
    ruleTransferLog.push({
      config: t('分路径回源配置(Origin.PathBasedOrigin)'),
      result: t('未配置'),
      detail: ''
    });
    genLog.defaultLog(`${t('分路径回源配置(Origin.PathBasedOrigin)')}${t('未配置')}`)
    return null;
  }

  const pathConfig = keyConfig.filter(rule => {
    return rule.RuleType === 'path';
  });

  if (pathConfig && pathConfig.length > 0) {
    genLog.errorLog(t('EO不支持修改全路径文件的回源配置'));
  }

  const newKeyConfig = keyConfig.filter(rule => {
    return rule.RuleType !== 'path';
  });

  const eoRules = [];
  newKeyConfig.reverse().forEach(rule => {
    const [origin, port, weight] = rule.Origin[0].split(':');

    let eoRule = {
      'Conditions': [
        {
          'Conditions': [
            {
              'Operator': 'equal',
              'Target': utils.getTarget(rule.RuleType),
              'IgnoreCase': false,
              'Values': rule.RuleType === 'path' ? rule.RulePaths.map(path => {
                return `https://${domain}${path}`;
              }) : rule.RulePaths
            }
          ]
        }
      ],
      'Actions': [
        {
          'NormalAction': {
            'Action': 'Origin',
            'Parameters': [
              {
                'Name': 'Type',
                'Values': [
                  'IP_DOMAIN'
                ]
              },
              {
                'Name': 'DomainName',
                'Values': [origin]
              },
              {
                'Name': 'OriginProtocol',
                'Values': [
                  'follow'
                ]
              },
              {
                'Name': 'HttpOriginPort',
                'Values': [port !== undefined ? port : '80']
              },
              {
                'Name': 'HttpsOriginPort',
                'Values': [port !== undefined ? port : '443']
              }
            ]
          }
        }
      ]
    };
    eoRules.push(eoRule);

  });

  if (pathConfig && pathConfig.length > 0) {
    ruleTransferLog.push({
      config: t('分路径回源配置(Origin.PathBasedOrigin)'),
      result: t('部分失败'),
      detail: t('EO不支持修改全路径文件的回源配置')
    });
    genLog.warnLog(`${t('EO不支持修改全路径文件的回源配置')}: ${t('EO不支持修改全路径文件的回源配置')}`)
  }
  else {
    ruleTransferLog.push({
      config: t('分路径回源配置(Origin.PathBasedOrigin)'),
      result: t('成功'),
      detail: ''
    });
    genLog.successLog(`${t('分路径回源配置(Origin.PathBasedOrigin)')}: ${t('成功')}`)
  }
  return {
    'Rules': eoRules,
    'Tags': []
  };
}

module.exports = PathBasedOrigin;
